package com.gyee.table.controller;

import cn.hutool.core.util.ObjectUtil;
import com.gyee.table.entity.SysUser;
import com.gyee.table.jwt.annotation.UserLoginToken;
import com.gyee.table.jwt.utils.JwtUtils;
import com.gyee.table.service.ISysUserService;
import com.gyee.table.utils.StringUtil;
import com.gyee.table.vo.AjaxResult;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;

/**
 * 用户登录操作接口
 *
 * @author hlf
 * @date 2023/3/28 14:55
 * 文件说明：
 */
@Controller
public class LoginController {

    @Resource
    private ISysUserService userService;

    /**
     * 登录
     *
     * @param username 用户名
     * @param password 密码
     * @return
     */
    @PostMapping("/toLogin/{username}/{password}")
    @ResponseBody
    @UserLoginToken
    public AjaxResult jwtLogin(@PathVariable String username, @PathVariable String password) {
        if (StringUtil.isEmpty(username) || StringUtil.isEmpty(password)) {
            return AjaxResult.error("账号和密码不能为空!");
        }
        SysUser user = userService.selectUserByLoginName(username);
        if (user == null) {
            return AjaxResult.error("用户不存在/密码错误!");
        }
        if (ObjectUtil.isNull(userService.checkPassword(username, password))) {
            return AjaxResult.error("用户不存在/密码错误!");
        }
        String token = JwtUtils.createToken(username, user.getPassword());
        return AjaxResult.success("登录成功,请妥善保管您的token信息").put("token", token).put("id", user.getId()).put("loginName", user.getLoginName()).put("userName", user.getUserName()).put("userAuthority", user.getUserAuthority());
    }
}
