package com.gyee.table.jwt.filter;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.auth0.jwt.exceptions.JWTDecodeException;
import com.gyee.table.entity.SysUser;
import com.gyee.table.jwt.annotation.PassToken;
import com.gyee.table.jwt.annotation.UserLoginToken;
import com.gyee.table.jwt.utils.JwtUtils;
import com.gyee.table.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Method;

/**
 * @author hlf
 * @date 2023/4/1 16:26
 * 文件说明：jwt 自定义拦截器
 */
public class JwtFilter implements HandlerInterceptor {

    @Autowired
    private ISysUserService userService;

    /*
    controller执行之前
     */
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object object) {
        // 从http请求头中取出token
        String token = request.getHeader("token");
        // 如果不是映射到方法直接通过
        if (!(object instanceof HandlerMethod)) {
            return true;
        }
        HandlerMethod handlerMethod = (HandlerMethod) object;
        Method method = handlerMethod.getMethod();
        // 方法是否带有UserLoginToken注释
        if (method.isAnnotationPresent(UserLoginToken.class)) {
            UserLoginToken userLoginToken = method.getAnnotation(UserLoginToken.class);
            if (userLoginToken.required()) {
                return true;
            }
        }
        // 方法是否带有PassToken注释
        if (method.isAnnotationPresent(PassToken.class)) {
            PassToken passToken = method.getDeclaredAnnotation(PassToken.class);
            if (passToken.required()) {
                // 执行认证
                if (StrUtil.isEmpty(token)) {
                    throw new RuntimeException("消息头不正确，header需要携带token参数");
                }
                // 获取token中的username
                String username;
                try {
                    username = JwtUtils.getUserName(token);
                } catch (JWTDecodeException j) {
                    throw new RuntimeException("访问异常！");
                }
                SysUser user = userService.selectUserByLoginName(username);
                if (ObjectUtil.isNull(user)) {
                    throw new RuntimeException("当前用户不存在，请重新登录！");
                }
                JwtUtils.verify(user.getLoginName(), user.getPassword(), token);
                return true;
            }
        }
        return true;
    }

    /*
    controller执行后，页面渲染前
     */
    @Override
    public void postHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, ModelAndView modelAndView) throws Exception {

    }

    /*
    页面渲染后
     */
    @Override
    public void afterCompletion(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, Exception e) throws Exception {

    }

}
